$\texttt{tropygal}$ is a pure-python package for entropy estimates in
the context of galacitc dynamics, but can be used in other contexts
too. It also provides functions for analytical distribution functions
and density of states for models that have analytical
expressions.

Read the docs [here](https://tropygal.readthedocs.io/en/latest/).

Detailed expressions and numerical tests can be found in [Beraldo e
Silva et al
2024](https://ui.adsabs.harvard.edu/abs/2024arXiv240707947B/abstract). Please,
cite this paper if you use $\texttt{tropygal}$.